# ibus-hiragana - Hiragana IME for IBus
#
# Copyright (c) 2020-2024 Esrille Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import gettext
import os

import gi
gi.require_version('GLib', '2.0')
from gi.repository import GLib


def get_name():
    return 'ibus-hiragana'


def get_version():
    return '0.15.10'


def get_prefix():
    return '/usr'


def get_datadir():
    return '/usr/share/ibus-hiragana'


def get_user_datadir():
    return os.path.join(GLib.get_user_data_dir(), 'ibus-hiragana')


def get_libexecdir():
    return '/usr/libexec'


def get_localedir():
    return '/usr/share/locale'


def load_from_data_dirs(file):
    data_dirs = [get_user_datadir(), get_datadir()]
    for dir_path in data_dirs:
        path = os.path.join(dir_path, file)
        if os.path.exists(path):
            return path
    return None


def _(text):
    return gettext.dgettext(get_name(), text)
